==> ilu-2.0.0.6-1.tar.gz: ilu-2.0.0.6/stubbers/python/manifest.h <==
/*
Copyright (c) 1991, 1992, 1993, 1994 Xerox Corporation.  All Rights Reserved.

Unlimited use, reproduction, and distribution of this software is
permitted.  Any copy of this software must include both the above
copyright notice of Xerox Corporation and this paragraph.  Any
distribution of this software must comply with all applicable United
States export control laws.  This software is made available AS IS,
and XEROX CORPORATION DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED,
INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS FOR A PARTICULAR PURPOSE, AND NOTWITHSTANDING ANY OTHER
PROVISION CONTAINED HEREIN, ANY LIABILITY FOR DAMAGES RESULTING FROM
THE SOFTWARE OR ITS USE IS EXPRESSLY DISCLAIMED, WHETHER ARISING IN
CONTRACT, TORT (INCLUDING NEGLIGENCE) OR STRICT LIABILITY, EVEN IF
XEROX CORPORATION IS ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

$Id: manifest.h,v 1.6 1994/11/22 21:58:59 severson Exp $
*/

extern const char	fmtEnumImageDict[];
extern const char	fmtEnumLit[];
extern const char	fmtFileName[];
extern const char	fmtFuncIo[];
extern const char	fmtFuncSkel[];
extern const char	fmtSkelModuleName[];
extern const char	fmtUnionDiscrimLit[];

extern const char	prefixIdlAttribute[];

extern const char	prefixFuncEnd[];
extern const char	prefixFuncInput[];
extern const char	prefixFuncOutput[];
extern const char	prefixFuncSizeOf[];

extern const char	nameClassSkel[];
extern const char	nameClassStub[];
extern const char	nameExceptUnimpl[];
extern const char	nameFuncCatchExcept[];
extern const char	nameFuncSendExcept[];
extern const char	nameModuleIlu[];
extern const char	nameVarCall[];
extern const char	nameVarClass[];
extern const char	nameVarDiscrim[];
extern const char	nameVarExceptCode[];
extern const char	nameVarExceptName[];
extern const char	nameVarExceptValue[];
extern const char	nameVarIndex[];
extern const char	nameVarLength[];
extern const char	nameVarMstid[];
extern const char	nameVarResult[];
extern const char	nameVarSbh[];
extern const char	nameVarSelf[];
extern const char	nameVarSize[];
extern const char	nameVarValue[];

==> ilu_2.0.0.12.orig.tar.gz: ilu-2.0.0.12.orig/stubbers/python/manifest.h <==
/*
Copyright (c) 1991, 1992, 1993, 1994 Xerox Corporation.  All Rights Reserved.

Unlimited use, reproduction, and distribution of this software is
permitted.  Any copy of this software must include both the above
copyright notice of Xerox Corporation and this paragraph.  Any
distribution of this software must comply with all applicable United
States export control laws.  This software is made available AS IS,
and XEROX CORPORATION DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED,
INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS FOR A PARTICULAR PURPOSE, AND NOTWITHSTANDING ANY OTHER
PROVISION CONTAINED HEREIN, ANY LIABILITY FOR DAMAGES RESULTING FROM
THE SOFTWARE OR ITS USE IS EXPRESSLY DISCLAIMED, WHETHER ARISING IN
CONTRACT, TORT (INCLUDING NEGLIGENCE) OR STRICT LIABILITY, EVEN IF
XEROX CORPORATION IS ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

$Id: manifest.h,v 1.10 1997/05/14 00:11:26 janssen Exp $
*/

extern const char	fmtEnumImageDict[];
extern const char	fmtEnumLit[];
extern const char	fmtFileName[];
extern const char	fmtFuncIo[];
extern const char	fmtFuncSkel[];
extern const char	fmtSkelModuleName[];
extern const char	fmtUnionDiscrimLit[];

extern const char	prefixIdlAttribute[];
extern const char	prefixIdlExcType[];

extern const char	prefixFuncEnd[];
extern const char	prefixFuncInput[];
extern const char	prefixFuncOutput[];
extern const char	prefixFuncSizeOf[];

extern const char	nameClassSkel[];
extern const char	nameClassStub[];
extern const char	nameExceptUnimpl[];
extern const char	nameFuncCatchExcept[];
extern const char	nameFuncSendExcept[];
extern const char	nameFuncCatchValue[];
extern const char	nameFuncPutValue[];
extern const char	nameFuncSizeValue[];
extern const char	nameFuncVariantInput[];
extern const char	nameFuncVariantOutSize[];
extern const char	nameFuncCacheAccess[];
extern const char	nameFuncCacheValue[];
extern const char	nameExceptRetry[];
extern const char	nameModuleIlu[];
extern const char	nameVarCache[];
extern const char	nameVarCall[];
extern const char	nameVarTemp[];
extern const char	nameVarType[];
extern const char	nameVarClass[];
extern const char	nameVarDiscrim[];
extern const char	nameVarExceptCode[];
extern const char	nameVarExceptName[];
extern const char	nameVarExceptValue[];
extern const char	nameVarTypeUID[];
extern const char	nameVarValueValue[];
extern const char	nameVarIndex[];
extern const char	nameVarLength[];
extern const char	nameVarMstid[];
extern const char	nameVarResult[];
extern const char	nameVarSbh[];
extern const char	nameVarSelf[];
extern const char	nameVarSize[];
extern const char	nameVarValue[];
